<?php

class ITSEC_Core_Admin {

	function run() {
		add_filter( 'itsec_meta_links', array( $this, 'add_plugin_meta_links' ) );
		add_filter( 'itsec_support_url', array( $this, 'itsec_support_url' ) );

		add_action( 'itsec-settings-page-init', array( $this, 'init_settings_page' ) );
		add_action( 'itsec-logs-page-init', array( $this, 'init_settings_page' ) );
		add_action( 'admin_enqueue_scripts', array( $this, 'register_scripts' ), 0 );
	}

	public function init_settings_page() {
		if ( ! class_exists( 'backupbuddy_api' ) ) {
			require_once( dirname( __FILE__ ) . '/sidebar-widget-backupbuddy-cross-promo.php' );
		}
		require_once( dirname( __FILE__ ) . '/sidebar-widget-support.php' );
	}

	/**
	 * Adds links to the plugin row meta
	 *
	 * @since 4.0
	 *
	 * @param array $meta Existing meta
	 *
	 * @return array
	 */
	public function add_plugin_meta_links( $meta ) {

		$meta[] = '<a href="http://ithemes.com/member/support.php" target="_blank" rel="noopener noreferrer">' . __( 'Get Support', 'it-l10n-ithemes-security-pro' ) . '</a>';

		return $meta;
	}

	public function itsec_support_url( $support_url ) {
		return 'http://ithemes.com/member/support.php';
	}

	public function register_scripts() {
		$dir      = ITSEC_Core::get_plugin_dir();
		$manifest = require $dir . 'manifest.php';

		foreach ( $manifest as $name => $config ) {

			$handle = $this->name_to_handle( $name );

			if ( defined( 'SCRIPT_DEBUG' ) && SCRIPT_DEBUG && file_exists( $dir . $name . '.js' ) ) {
				$file     = $name . '.js';
				$is_debug = true;
			} else {
				$file     = $name . '.min.js';
				$is_debug = false;
			}

			$deps = $config['dependencies'];

			if ( $is_debug ) {
				$version = filemtime( $dir . $file );
			} else {
				$version = $config['hash'];

				foreach ( $config['vendors'] as $vendor ) {
					$deps[] = $this->name_to_handle( $vendor );
				}
			}

			wp_register_script(
				$handle,
				plugins_url( $file, ITSEC_Core::get_plugin_file() ),
				$deps,
				$version
			);
		}
	}

	private function name_to_handle( $name ) {
		$name = str_replace( '/js/', '/entry/', $name );

		return 'itsec-' . str_replace( '/', '-', $name );
	}
}
